Usage
LRA(group_by_individual, times, timejump, output_style = 1, min_time = NULL,
max_time = NULL, identities = NULL, which_identities = NULL, locations = NULL,
which_locations = NULL, start_time = NULL, end_time = NULL, classes = NULL,
which_classes = NULL, association_rate = TRUE)
Arguments
group_by_individual
a K x N matrix of K groups (observations, gathering events, etc.) and N individuals (all individuals that are present in at least one group)
times
K vector of times defining the middle of each group/event
timejump
step length for tau
output_style
either 1 or 2, see details
min_time
minimum/starting value of tau
max_time
maximum/ending value of tau
identities
N vector of identifiers for each individual (column) in the group by individual matrix
which_identities
vector of identities to include in the network (subset of identities)
locations
K vector of locations defining the location of each group/event
which_locations
vector of locations to include in the network (subset of locations)
start_time
element describing the starting time for inclusion in the network (useful for temporal analysis)
end_time
element describing the ending time for inclusion in the network (useful for temporal analysis)
classes
N vector of types or class of each individual (column) in the group by individual matrix (for subsetting)
which_classes
vector of class(es)/type(s) to include in the network (subset of classes)
association_rate
calculate lagged rate of association (see details)